From: Dmitry Torokhov <dtor_core@ameritech.net>
To: Vojtech Pavlik <vojtech@suse.cz>
Cc: Andrew Morton <akpm@osdl.org>, linux-kernel@vger.kernel.org
Subject: [PATCH 1/7] i8042 suspend
Date: Sat, 3 Jan 2004 03:56:45 -0500 [thread overview]
Message-ID: <200401030356.48071.dtor_core@ameritech.net> (raw)
In-Reply-To: <200401030350.43437.dtor_core@ameritech.net>
===================================================================
ChangeSet@1.1571, 2004-01-02 00:22:32-05:00, dtor_core@ameritech.net
Input: Add suspend methods to restore original controller state
on suspend as some BIOS don't like the state we leave it in.
Also synchroniously delete the polling timer on module exit.
i8042.c | 76 +++++++++++++++++++++++++++++++++++++++++++++-------------------
1 files changed, 54 insertions(+), 22 deletions(-)
===================================================================
diff -Nru a/drivers/input/serio/i8042.c b/drivers/input/serio/i8042.c
--- a/drivers/input/serio/i8042.c Sat Jan 3 03:07:29 2004
+++ b/drivers/input/serio/i8042.c Sat Jan 3 03:07:29 2004
@@ -746,6 +746,29 @@
/*
+ * Reset the controller.
+ */
+void i8042_controller_reset(void)
+{
+ if (i8042_reset) {
+ unsigned char param;
+
+ if (i8042_command(¶m, I8042_CMD_CTL_TEST))
+ printk(KERN_ERR "i8042.c: i8042 controller reset timeout.\n");
+ }
+
+/*
+ * Restore the original control register setting.
+ */
+
+ i8042_ctr = i8042_initial_ctr;
+
+ if (i8042_command(&i8042_ctr, I8042_CMD_CTL_WCTR))
+ printk(KERN_WARNING "i8042.c: Can't restore CTR.\n");
+}
+
+
+/*
* Here we try to reset everything back to a state in which the BIOS will be
* able to talk to the hardware when rebooting.
*/
@@ -770,26 +793,20 @@
if (i8042_mux_values[i].exists)
serio_cleanup(i8042_mux_port + i);
-/*
- * Reset the controller.
- */
-
- if (i8042_reset) {
- unsigned char param;
+ i8042_controller_reset();
+}
- if (i8042_command(¶m, I8042_CMD_CTL_TEST))
- printk(KERN_ERR "i8042.c: i8042 controller reset timeout.\n");
- }
/*
- * Restore the original control register setting.
+ * Here we try to restore the original BIOS settings
*/
- i8042_ctr = i8042_initial_ctr;
-
- if (i8042_command(&i8042_ctr, I8042_CMD_CTL_WCTR))
- printk(KERN_WARNING "i8042.c: Can't restore CTR.\n");
+static int i8042_controller_suspend(void)
+{
+ del_timer_sync(&i8042_timer);
+ i8042_controller_reset();
+ return 0;
}
@@ -809,7 +826,7 @@
if (i8042_mux_present)
if (i8042_enable_mux_mode(&i8042_aux_values, NULL) ||
i8042_enable_mux_ports(&i8042_aux_values)) {
- printk(KERN_WARNING "i8042: failed to resume active multiplexor, mouse won't wotk.\n");
+ printk(KERN_WARNING "i8042: failed to resume active multiplexor, mouse won't work.\n");
}
/*
@@ -825,6 +842,10 @@
for (i = 0; i < 4; i++)
if (i8042_mux_values[i].exists && i8042_activate_port(i8042_mux_port + i) == 0)
serio_reconnect(i8042_mux_port + i);
+/*
+ * Restart timer (for polling "stuck" data)
+ */
+ mod_timer(&i8042_timer, jiffies + I8042_POLL_PERIOD);
return 0;
}
@@ -851,16 +872,22 @@
};
/*
* Resume handler for the new PM scheme (driver model)
*/
+static int i8042_suspend(struct sys_device *dev, u32 state)
+{
+ return i8042_controller_suspend();
+}
+
static int i8042_resume(struct sys_device *dev)
{
return i8042_controller_resume();
}
static struct sysdev_class kbc_sysclass = {
- set_kset_name("i8042"),
- .resume = i8042_resume,
+ set_kset_name("i8042"),
+ .suspend = i8042_suspend,
+ .resume = i8042_resume,
};
static struct sys_device device_i8042 = {
@@ -869,12 +896,17 @@
};
/*
* Resume handler for the old PM scheme (APM)
*/
static int i8042_pm_callback(struct pm_dev *dev, pm_request_t request, void *dummy)
{
- if (request == PM_RESUME)
- return i8042_controller_resume();
+ switch (request) {
+ case PM_SUSPEND:
+ return i8042_controller_suspend();
+
+ case PM_RESUME:
+ return i8042_controller_resume();
+ }
return 0;
}
@@ -955,7 +987,7 @@
sysdev_class_unregister(&kbc_sysclass);
}
- del_timer(&i8042_timer);
+ del_timer_sync(&i8042_timer);
i8042_controller_cleanup();
next prev parent reply other threads:[~2004-01-03 9:04 UTC|newest]
Thread overview: 39+ messages / expand[flat|nested] mbox.gz Atom feed top
2004-01-03 8:50 New set of input patches Dmitry Torokhov
2004-01-03 8:56 ` Dmitry Torokhov [this message]
2004-01-03 8:57 ` [PATCH 2/7] i8042 option parsing Dmitry Torokhov
2004-01-03 9:00 ` [PATCH 3/7] psmouse " Dmitry Torokhov
2004-01-03 9:01 ` [PATCH 4/7] atkbd " Dmitry Torokhov
2004-01-03 9:02 ` [PATCH 5/7] missing module licenses Dmitry Torokhov
2004-01-03 9:03 ` [PATCH 6/7] Kconfig Synaptics help Dmitry Torokhov
2004-01-03 9:03 ` [PATCH 7/7] SiS AUX port Dmitry Torokhov
2004-03-29 15:39 ` Dmitry Torokhov
2004-03-29 15:39 ` [PATCH 6/7] Kconfig Synaptics help Dmitry Torokhov
2004-03-29 15:39 ` [PATCH 5/7] missing module licenses Dmitry Torokhov
2004-01-03 10:07 ` [PATCH 3/7] psmouse option parsing Vojtech Pavlik
2004-01-03 17:29 ` Dmitry Torokhov
2004-01-03 17:38 ` Vojtech Pavlik
2004-03-29 15:40 ` Vojtech Pavlik
2004-03-29 15:40 ` Dmitry Torokhov
2004-03-29 15:39 ` [PATCH 4/7] atkbd " Dmitry Torokhov
2004-03-29 15:39 ` [PATCH 3/7] psmouse " Vojtech Pavlik
2004-03-29 15:39 ` Dmitry Torokhov
2004-01-03 10:03 ` [PATCH 1/7] i8042 suspend Vojtech Pavlik
2004-01-03 16:50 ` Dmitry Torokhov
2004-03-29 15:40 ` Dmitry Torokhov
2004-01-18 19:23 ` Russell King
2004-01-18 22:42 ` Dmitry Torokhov
2004-03-29 15:39 ` Vojtech Pavlik
2004-03-29 15:39 ` [PATCH 2/7] i8042 option parsing Dmitry Torokhov
2004-01-03 10:10 ` New set of input patches Vojtech Pavlik
2004-01-05 5:59 ` Dmitry Torokhov
2004-01-05 6:01 ` [PATCH 1/3] Fix compile error in 98busmouse.c module Dmitry Torokhov
2004-01-05 6:02 ` [PATCH 2/3] Convert mouse drivers to use module_param Dmitry Torokhov
2004-01-05 6:03 ` [PATCH 3/3] Convert tsdev " Dmitry Torokhov
2004-03-29 15:44 ` Dmitry Torokhov
2004-03-29 15:44 ` [PATCH 2/3] Convert mouse drivers " Dmitry Torokhov
2004-01-05 8:36 ` New set of input patches Vojtech Pavlik
2004-03-29 15:44 ` [PATCH 1/3] Fix compile error in 98busmouse.c module Dmitry Torokhov
2004-03-29 15:44 ` New set of input patches Vojtech Pavlik
2004-03-29 15:39 ` [PATCH 1/7] i8042 suspend Dmitry Torokhov
2004-03-29 15:39 ` New set of input patches Vojtech Pavlik
2004-03-29 15:44 ` Dmitry Torokhov
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=200401030356.48071.dtor_core@ameritech.net \
--to=dtor_core@ameritech.net \
--cc=akpm@osdl.org \
--cc=linux-kernel@vger.kernel.org \
--cc=vojtech@suse.cz \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -851,16 +872,22 @@
};
/*
- * Resume handler for the new PM scheme (driver model)
+ * Suspend/resume handlers for the new PM scheme (driver model)
*/
@@ -869,12 +896,17 @@
};
/*
- * Resume handler for the old PM scheme (APM)
+ * Suspend/resume handler for the old PM scheme (APM)
*/
static int i8042_pm_callback(struct pm_dev *dev, pm_request_t request, void *dummy)
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.